@@ -2,13 +2,12 @@ import sys
 import os
 import json
 import logging
-import rich_click as click
+import click
 import yaml
 import cisco
+import pprint
 from pathlib import Path
 from gtts import gTTS
-from rich import print_json
-from rich.console import Console
 from jinja2 import Environment, FileSystemLoader
 
 class NxPyDocs():
@@ -44,12 +43,13 @@ class NxPyDocs():
                             ]
 
     def nxpydocs(self):
+        pp = pprint.PrettyPrinter(indent=4)
         if self.command == "all":
             for single_command in self.supported_templates:
                 self.command = single_command
                 command_output = clid(f"{ self.command }")
                 parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
-                print_json(parsed_json)
+                pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -59,7 +59,7 @@ class NxPyDocs():
             if self.command in self.supported_templates:
                 command_output = clid(f"{ self.command }")
                 parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
-                print_json(parsed_json)
+                pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
